#
# Configure paths and flags for the AirTSP library.
# Denis Arnaud <denis_arnaud at users dot sourceforge dot net>, July 2008
#
# Note: the AIRTSP library depends upon BOOST to build.
# Your configure.ac must therefore define appropriately the BOOST
# variables (i.e., BOOST_CFLAGS, BOOST_LIBS, BOOST_DATE_TIME_LIB).
#
# Variables set by this macro:
#  * AIRTSP_VERSION
#  * AIRTSP_CFLAGS
#  * AIRTSP_LIBS
#  * AIRTSP_SAMPLE_DIR
#

AC_DEFUN([AM_PATH_AIRTSP],
[
AC_LANG_SAVE
AC_LANG([C++])

##
AC_ARG_WITH(airtsp,
	[ --with-airtsp=PFX Prefix where AirTSP is installed (optional) ],
	    airtsp_dir="$withval",
	    airtsp_dir="")

  if test "x${AIRTSP_CONFIG+set}" != xset ; then
     if test "x$airtsp_dir" != x ; then
         AIRTSP_CONFIG="$airtsp_dir/bin/airtsp-config"
     fi
  fi

  AC_PATH_PROG(AIRTSP_CONFIG, airtsp-config, no)

  ## Check whether Boost flags and libraries are defined
  # General Boost compilation flags
  AC_MSG_CHECKING(for BOOST_CFLAGS environment variable)
  if test x"${BOOST_CFLAGS}" = x; then
	AC_MSG_RESULT([Warning: AirTSP needs Boost, and the BOOST_CFLAGS environment variable does not appear to be set. It may not be a problem, though, if your Unix distribution is standard, that is, if Boost is installed in /usr. Otherwise, the AirTSP will fail to compile.])
  else
	AC_MSG_RESULT([ok (set to ${BOOST_CFLAGS})])
  fi

  # Boost Date-Time library
  AC_MSG_CHECKING(for BOOST_DATE_TIME_LIB environment variable)
  if test x"${BOOST_DATE_TIME_LIB}" = x; then
	AC_MSG_RESULT([Warning: AirTSP needs the Boost Date-Time library, and the BOOST_DATE_TIME_LIB environment variable does not appears to be set. The AirTSP may fail to link.])
  else
	AC_MSG_RESULT([ok (set to ${BOOST_DATE_TIME_LIB})])
  fi

  # Boost Program Options library
  AC_MSG_CHECKING(for BOOST_PROGRAM_OPTIONS_LIB environment variable)
  if test x"${BOOST_PROGRAM_OPTIONS_LIB}" = x; then
	AC_MSG_RESULT([Warning: AirTSP needs the Boost Program Options library, and the BOOST_PROGRAM_OPTIONS_LIB environment variable does not appears to be set. The AirTSP may fail to link.])
  else
	AC_MSG_RESULT([ok (set to ${BOOST_PROGRAM_OPTIONS_LIB})])
  fi

  # Boost File System library
  AC_MSG_CHECKING(for BOOST_FILESYSTEM_LIB environment variable)
  if test x"${BOOST_FILESYSTEM_LIB}" = x; then
	AC_MSG_RESULT([Warning: AirTSP needs the Boost Date-Time library, and the BOOST_FILESYSTEM_LIB environment variable does not appears to be set. The AirTSP may fail to link.])
  else
	AC_MSG_RESULT([ok (set to ${BOOST_FILESYSTEM_LIB})])
  fi

  ## AirTSP version
  min_airtsp_version=ifelse([$1], ,0.1.0,$1)
  AC_MSG_CHECKING(for AirTSP - version >= $min_airtsp_version)
  no_airtsp=""
  if test "${AIRTSP_CONFIG}" = "no" ; then
     no_airtsp=yes
     AC_MSG_RESULT([no])
  else
     AIRTSP_VERSION=`${AIRTSP_CONFIG} --version`
     AIRTSP_CFLAGS=`${AIRTSP_CONFIG} --cflags`
     AIRTSP_CFLAGS="${BOOST_CFLAGS} ${AIRTSP_CFLAGS}"
     AIRTSP_LIBS=`${AIRTSP_CONFIG} --libs`
     AIRTSP_LIBS="${BOOST_LIBS} ${BOOST_DATE_TIME_LIB} ${AIRTSP_LIBS}"
     AIRTSP_SAMPLE_DIR=`${AIRTSP_CONFIG} --sampledir`

     AC_SUBST([AIRTSP_VERSION])
     AC_SUBST([AIRTSP_CFLAGS])
     AC_SUBST([AIRTSP_LIBS])
     AC_SUBST([AIRTSP_SAMPLE_DIR])

    airtsp_major_version=`echo ${AIRTSP_VERSION} | sed 's/^\([[0-9]]*\).*/\1/'`
    if test "x${airtsp_major_version}" = "x" ; then
       airtsp_major_version=0
    fi

    airtsp_minor_version=`echo ${AIRTSP_VERSION} | \
						sed 's/^\([[0-9]]*\)\.\{0,1\}\([[0-9]]*\).*/\2/'`
    if test "x${airtsp_minor_version}" = "x" ; then
       airtsp_minor_version=0
    fi

    airtsp_micro_version=`echo ${AIRTSP_VERSION} | \
          sed 's/^\([[0-9]]*\)\.\{0,1\}\([[0-9]]*\)\.\{0,1\}\([[0-9]]*\).*/\3/'`
    if test "x${airtsp_micro_version}" = "x" ; then
       airtsp_micro_version=0
    fi

    ## Simple test of compilation and link
    SAVED_CPPFLAGS="${CPPFLAGS}"
    SAVED_LDFLAGS="${LDFLAGS}"
    CPPFLAGS="${CPPFLAGS} ${BOOST_CFLAGS} ${AIRTSP_CFLAGS}"
    LDFLAGS="${LDFLAGS} ${AIRTSP_LIBS}"


    AC_COMPILE_IFELSE(
		[AC_LANG_PROGRAM([[#include <airtsp/AIRTSP_Service.hpp>
				]],
				[[int i=0;]]
		)]
		,

    	[AC_MSG_RESULT([yes (${AIRTSP_VERSION})])],

	[AC_MSG_ERROR([We could not compile a simple AirTSP example. See config.log.])]
    )

    CPPFLAGS="${SAVED_CPPFLAGS}"
    LDFLAGS="${SAVED_LDFLAGS}"

  fi

AC_LANG_RESTORE
])
